@@ -387,7 +387,6 @@ impl Cursor<'_> {
         while let Some(c) = self.bump() {
             match c {
                 '$' => {
-                    self.bump();
                     break;
                 }
                 _ => {
@@ -530,7 +529,7 @@ mod tests {
         }
     }
 
-    fn lex(input: &str) -> Vec<TokenDebug> {
+    fn lex(input: &str) -> Vec<TokenDebug<'_>> {
         let mut tokens = vec![];
         let mut start = 0;
 
@@ -755,4 +754,13 @@ U&"d!0061t!+000061" UESCAPE '!'
 "foo "" bar"
 "#))
     }
+
+    #[test]
+    fn dollar_quoted_string() {
+        assert_debug_snapshot!(lex("$$$$"), @r#"
+        [
+            "$$$$" @ Literal { kind: DollarQuotedString { terminated: true } },
+        ]
+        "#);
+    }
 }
