@@ -8,13 +8,14 @@ use ignore::find_ignores;
 use ignore_index::IgnoreIndex;
 use rowan::TextRange;
 use rowan::TextSize;
-use serde::{Deserialize, Serialize};
+use serde::Deserialize;
 
 use squawk_syntax::SyntaxNode;
 use squawk_syntax::{Parse, SourceFile};
 
 pub use version::Version;
 
+pub mod analyze;
 pub mod ignore;
 mod ignore_index;
 mod version;
@@ -38,6 +39,7 @@ use rules::ban_drop_database;
 use rules::ban_drop_not_null;
 use rules::ban_drop_table;
 use rules::ban_truncate_cascade;
+use rules::ban_uncommitted_transaction;
 use rules::changing_column_type;
 use rules::constraint_missing_not_valid;
 use rules::disallow_unique_constraint;
@@ -51,69 +53,43 @@ use rules::renaming_column;
 use rules::renaming_table;
 use rules::require_concurrent_index_creation;
 use rules::require_concurrent_index_deletion;
+use rules::require_timeout_settings;
 use rules::transaction_nesting;
 // xtask:new-rule:rule-import
 
-#[derive(Debug, PartialEq, Clone, Copy, Serialize, Hash, Eq, Deserialize, Sequence)]
+#[derive(Debug, PartialEq, Clone, Copy, Hash, Eq, Sequence)]
 pub enum Rule {
-    #[serde(rename = "require-concurrent-index-creation")]
     RequireConcurrentIndexCreation,
-    #[serde(rename = "require-concurrent-index-deletion")]
     RequireConcurrentIndexDeletion,
-    #[serde(rename = "constraint-missing-not-valid")]
     ConstraintMissingNotValid,
-    #[serde(rename = "adding-field-with-default")]
     AddingFieldWithDefault,
-    #[serde(rename = "adding-foreign-key-constraint")]
     AddingForeignKeyConstraint,
-    #[serde(rename = "changing-column-type")]
     ChangingColumnType,
-    #[serde(rename = "adding-not-nullable-field")]
     AddingNotNullableField,
-    #[serde(rename = "adding-serial-primary-key-field")]
     AddingSerialPrimaryKeyField,
-    #[serde(rename = "renaming-column")]
     RenamingColumn,
-    #[serde(rename = "renaming-table")]
     RenamingTable,
-    #[serde(rename = "disallowed-unique-constraint")]
     DisallowedUniqueConstraint,
-    #[serde(rename = "ban-drop-database")]
     BanDropDatabase,
-    #[serde(rename = "prefer-bigint-over-int")]
     PreferBigintOverInt,
-    #[serde(rename = "prefer-bigint-over-smallint")]
     PreferBigintOverSmallint,
-    #[serde(rename = "prefer-identity")]
     PreferIdentity,
-    #[serde(rename = "prefer-robust-stmts")]
     PreferRobustStmts,
-    #[serde(rename = "prefer-text-field")]
     PreferTextField,
-    #[serde(rename = "prefer-timestamptz")]
     PreferTimestampTz,
-    #[serde(rename = "ban-char-field")]
     BanCharField,
-    #[serde(rename = "ban-drop-column")]
     BanDropColumn,
-    #[serde(rename = "ban-drop-table")]
     BanDropTable,
-    #[serde(rename = "ban-drop-not-null")]
     BanDropNotNull,
-    #[serde(rename = "transaction-nesting")]
     TransactionNesting,
-    #[serde(rename = "adding-required-field")]
     AddingRequiredField,
-    #[serde(rename = "ban-concurrent-index-creation-in-transaction")]
     BanConcurrentIndexCreationInTransaction,
-    #[serde(rename = "unused-ignore")]
     UnusedIgnore,
-    #[serde(rename = "ban-create-domain-with-constraint")]
     BanCreateDomainWithConstraint,
-    #[serde(rename = "ban-alter-domain-with-add-constraint")]
     BanAlterDomainWithAddConstraint,
-    #[serde(rename = "ban-truncate-cascade")]
     BanTruncateCascade,
+    RequireTimeoutSettings,
+    BanUncommittedTransaction,
     // xtask:new-rule:error-name
 }
 
@@ -154,6 +130,8 @@ impl TryFrom<&str> for Rule {
             "ban-create-domain-with-constraint" => Ok(Rule::BanCreateDomainWithConstraint),
             "ban-alter-domain-with-add-constraint" => Ok(Rule::BanAlterDomainWithAddConstraint),
             "ban-truncate-cascade" => Ok(Rule::BanTruncateCascade),
+            "require-timeout-settings" => Ok(Rule::RequireTimeoutSettings),
+            "ban-uncommitted-transaction" => Ok(Rule::BanUncommittedTransaction),
             // xtask:new-rule:str-name
             _ => Err(format!("Unknown violation name: {s}")),
         }
@@ -176,7 +154,7 @@ impl std::error::Error for UnknownRuleName {}
 impl std::str::FromStr for Rule {
     type Err = UnknownRuleName;
     fn from_str(s: &str) -> Result<Self, Self::Err> {
-        serde_plain::from_str(s).map_err(|_| UnknownRuleName { val: s.to_string() })
+        Rule::try_from(s).map_err(|_| UnknownRuleName { val: s.to_string() })
     }
 }
 
@@ -214,12 +192,24 @@ impl fmt::Display for Rule {
             Rule::UnusedIgnore => "unused-ignore",
             Rule::BanAlterDomainWithAddConstraint => "ban-alter-domain-with-add-constraint",
             Rule::BanTruncateCascade => "ban-truncate-cascade",
+            Rule::RequireTimeoutSettings => "require-timeout-settings",
+            Rule::BanUncommittedTransaction => "ban-uncommitted-transaction",
             // xtask:new-rule:variant-to-name
         };
         write!(f, "{val}")
     }
 }
 
+impl<'de> Deserialize<'de> for Rule {
+    fn deserialize<D>(deserializer: D) -> Result<Self, D::Error>
+    where
+        D: serde::Deserializer<'de>,
+    {
+        let s = String::deserialize(deserializer)?;
+        s.parse().map_err(serde::de::Error::custom)
+    }
+}
+
 #[derive(Debug, Clone, PartialEq, Eq)]
 pub struct Fix {
     pub title: String,
@@ -238,6 +228,7 @@ impl Fix {
 #[derive(Debug, Clone, PartialEq, Eq)]
 pub struct Edit {
     pub text_range: TextRange,
+    // TODO: does this need to be an Option?
     pub text: Option<String>,
 }
 impl Edit {
@@ -253,6 +244,12 @@ impl Edit {
             text: Some(text.into()),
         }
     }
+    pub fn delete(text_range: TextRange) -> Self {
+        Self {
+            text_range,
+            text: None,
+        }
+    }
 }
 
 #[derive(Debug, Clone, PartialEq, Eq)]
@@ -272,8 +269,7 @@ impl Violation {
 
         let start = node
             .children_with_tokens()
-            .filter(|x| !x.kind().is_trivia())
-            .next()
+            .find(|x| !x.kind().is_trivia())
             .map(|x| x.text_range().start())
             // Not sure we actually hit this, but just being safe
             .unwrap_or_else(|| range.start());
@@ -333,91 +329,97 @@ impl Linter {
     #[must_use]
     pub fn lint(&mut self, file: &Parse<SourceFile>, text: &str) -> Vec<Violation> {
         if self.rules.contains(&Rule::AddingFieldWithDefault) {
-            adding_field_with_default(self, &file);
+            adding_field_with_default(self, file);
         }
         if self.rules.contains(&Rule::AddingForeignKeyConstraint) {
-            adding_foreign_key_constraint(self, &file);
+            adding_foreign_key_constraint(self, file);
         }
         if self.rules.contains(&Rule::AddingNotNullableField) {
-            adding_not_null_field(self, &file);
+            adding_not_null_field(self, file);
         }
         if self.rules.contains(&Rule::AddingSerialPrimaryKeyField) {
-            adding_primary_key_constraint(self, &file);
+            adding_primary_key_constraint(self, file);
         }
         if self.rules.contains(&Rule::AddingRequiredField) {
-            adding_required_field(self, &file);
+            adding_required_field(self, file);
         }
         if self.rules.contains(&Rule::BanDropDatabase) {
-            ban_drop_database(self, &file);
+            ban_drop_database(self, file);
         }
         if self.rules.contains(&Rule::BanCharField) {
-            ban_char_field(self, &file);
+            ban_char_field(self, file);
         }
         if self
             .rules
             .contains(&Rule::BanConcurrentIndexCreationInTransaction)
         {
-            ban_concurrent_index_creation_in_transaction(self, &file);
+            ban_concurrent_index_creation_in_transaction(self, file);
         }
         if self.rules.contains(&Rule::BanDropColumn) {
-            ban_drop_column(self, &file);
+            ban_drop_column(self, file);
         }
         if self.rules.contains(&Rule::BanDropNotNull) {
-            ban_drop_not_null(self, &file);
+            ban_drop_not_null(self, file);
         }
         if self.rules.contains(&Rule::BanDropTable) {
-            ban_drop_table(self, &file);
+            ban_drop_table(self, file);
         }
         if self.rules.contains(&Rule::ChangingColumnType) {
-            changing_column_type(self, &file);
+            changing_column_type(self, file);
         }
         if self.rules.contains(&Rule::ConstraintMissingNotValid) {
-            constraint_missing_not_valid(self, &file);
+            constraint_missing_not_valid(self, file);
         }
         if self.rules.contains(&Rule::DisallowedUniqueConstraint) {
-            disallow_unique_constraint(self, &file);
+            disallow_unique_constraint(self, file);
         }
         if self.rules.contains(&Rule::PreferBigintOverInt) {
-            prefer_bigint_over_int(self, &file);
+            prefer_bigint_over_int(self, file);
         }
         if self.rules.contains(&Rule::PreferBigintOverSmallint) {
-            prefer_bigint_over_smallint(self, &file);
+            prefer_bigint_over_smallint(self, file);
         }
         if self.rules.contains(&Rule::PreferIdentity) {
-            prefer_identity(self, &file);
+            prefer_identity(self, file);
         }
         if self.rules.contains(&Rule::PreferRobustStmts) {
-            prefer_robust_stmts(self, &file);
+            prefer_robust_stmts(self, file);
         }
         if self.rules.contains(&Rule::PreferTextField) {
-            prefer_text_field(self, &file);
+            prefer_text_field(self, file);
         }
         if self.rules.contains(&Rule::PreferTimestampTz) {
-            prefer_timestamptz(self, &file);
+            prefer_timestamptz(self, file);
         }
         if self.rules.contains(&Rule::RenamingColumn) {
-            renaming_column(self, &file);
+            renaming_column(self, file);
         }
         if self.rules.contains(&Rule::RenamingTable) {
-            renaming_table(self, &file);
+            renaming_table(self, file);
         }
         if self.rules.contains(&Rule::RequireConcurrentIndexCreation) {
-            require_concurrent_index_creation(self, &file);
+            require_concurrent_index_creation(self, file);
         }
         if self.rules.contains(&Rule::RequireConcurrentIndexDeletion) {
-            require_concurrent_index_deletion(self, &file);
+            require_concurrent_index_deletion(self, file);
         }
         if self.rules.contains(&Rule::BanCreateDomainWithConstraint) {
-            ban_create_domain_with_constraint(self, &file);
+            ban_create_domain_with_constraint(self, file);
         }
         if self.rules.contains(&Rule::BanAlterDomainWithAddConstraint) {
-            ban_alter_domain_with_add_constraint(self, &file);
+            ban_alter_domain_with_add_constraint(self, file);
         }
         if self.rules.contains(&Rule::TransactionNesting) {
-            transaction_nesting(self, &file);
+            transaction_nesting(self, file);
         }
         if self.rules.contains(&Rule::BanTruncateCascade) {
-            ban_truncate_cascade(self, &file);
+            ban_truncate_cascade(self, file);
+        }
+        if self.rules.contains(&Rule::RequireTimeoutSettings) {
+            require_timeout_settings(self, file);
+        }
+        if self.rules.contains(&Rule::BanUncommittedTransaction) {
+            ban_uncommitted_transaction(self, file);
         }
         // xtask:new-rule:rule-call
 
@@ -471,3 +473,24 @@ impl Linter {
         }
     }
 }
+
+#[cfg(test)]
+mod tests {
+    use insta::assert_debug_snapshot;
+
+    use super::*;
+
+    #[test]
+    fn prefer_timestamp_aliases() {
+        let rule1: Rule = "prefer-timestamp-tz".parse().unwrap();
+        let rule2: Rule = "prefer-timestamptz".parse().unwrap();
+        assert_eq!(rule1, rule2);
+        assert_debug_snapshot!(rule1, @"PreferTimestampTz");
+    }
+
+    #[test]
+    fn invalid_rule_name() {
+        let result: Result<Rule, _> = "invalid-rule-name".parse();
+        assert!(result.is_err());
+    }
+}
