@@ -21,17 +21,17 @@ lazy_static! {
 }
 
 fn is_char_type(x: TokenText<'_>) -> bool {
-    CHAR_TYPES.contains(&Identifier::new(&x.to_string()))
+    CHAR_TYPES.contains(&Identifier::new(x.as_ref()))
 }
 
 fn create_fix(range: TextRange, args: Option<ast::ArgList>) -> Fix {
     if let Some(args_list) = args {
         let end = args_list.syntax().text_range().start();
         let edit = Edit::replace(TextRange::new(range.start(), end), "varchar");
-        Fix::new(format!("Replace with `varchar`"), vec![edit])
+        Fix::new("Replace with `varchar`".to_string(), vec![edit])
     } else {
         let edit = Edit::replace(range, "text");
-        Fix::new(format!("Replace with `text`"), vec![edit])
+        Fix::new("Replace with `text`".to_string(), vec![edit])
     }
 }
 
@@ -40,15 +40,14 @@ fn check_path_type(ctx: &mut Linter, path_type: ast::PathType) {
         .path()
         .and_then(|x| x.segment())
         .and_then(|x| x.name_ref())
+        && is_char_type(name_ref.text())
     {
-        if is_char_type(name_ref.text()) {
-            let fix = create_fix(name_ref.syntax().text_range(), path_type.arg_list());
-            ctx.report(Violation::for_node(
-                Rule::BanCharField,
-                "Using `character` is likely a mistake and should almost always be replaced by `text` or `varchar`.".into(),
-                path_type.syntax(),
-            ).fix(Some(fix)));
-        }
+        let fix = create_fix(name_ref.syntax().text_range(), path_type.arg_list());
+        ctx.report(Violation::for_node(
+            Rule::BanCharField,
+            "Using `character` is likely a mistake and should almost always be replaced by `text` or `varchar`.".into(),
+            path_type.syntax(),
+        ).fix(Some(fix)));
     }
 }
 
