@@ -23,11 +23,10 @@ pub(crate) fn ban_create_domain_with_constraint(ctx: &mut Linter, parse: &Parse<
                         }
                     });
             if let Some(range) = range {
-                ctx.report(Violation::new(
+                ctx.report(Violation::for_range(
                 Rule::BanCreateDomainWithConstraint,
                     "Domains with constraints have poor support for online migrations. Use table and column constraints instead.".into(),
                     range,
-                    None,
                 ))
             }
         }
