@@ -10,12 +10,11 @@ pub(crate) fn ban_truncate_cascade(ctx: &mut Linter, parse: &Parse<SourceFile>)
                 // TODO: if we had knowledge about the entire schema, we
                 // could be more precise here and actually navigate the
                 // foreign keys.
-                ctx.report(Violation::new(
+                ctx.report(Violation::for_range(
                     Rule::BanTruncateCascade,
                     "Using `CASCADE` will recursively truncate any tables that foreign key to the referenced tables! So if you had foreign keys setup as `a <- b <- c` and truncated `a`, then `b` & `c` would also be truncated!".to_string(),
                     cascade.text_range(),
-                    "Remove the `CASCADE` and specify exactly which tables you want to truncate.".to_string(),
-                ));
+                ).help("Remove the `CASCADE` and specify exactly which tables you want to truncate."));
             }
         }
     }
