@@ -12,11 +12,10 @@ pub(crate) fn changing_column_type(ctx: &mut Linter, parse: &Parse<SourceFile>)
             for action in alter_table.actions() {
                 if let ast::AlterTableAction::AlterColumn(alter_column) = action {
                     if let Some(ast::AlterColumnOption::SetType(set_type)) = alter_column.option() {
-                        ctx.report(Violation::new(
+                        ctx.report(Violation::for_node(
                             Rule::ChangingColumnType,
                             "Changing a column type requires an `ACCESS EXCLUSIVE` lock on the table which blocks reads and writes while the table is rewritten. Changing the type of the column may also break other clients reading from the table.".into(),
-                            set_type.syntax().text_range(),
-                            None,
+                            set_type.syntax(),
                         ));
                     }
                 }
