@@ -67,13 +67,11 @@ fn not_valid_validate_in_transaction(
                             }
                         }
                         ast::AlterTableAction::AddConstraint(add_constraint) => {
-                            if add_constraint.not_valid().is_some() {
-                                if let Some(constraint) = add_constraint.constraint() {
-                                    if let Some(constraint_name) = constraint.name() {
-                                        not_valid_names
-                                            .insert(Identifier::new(&constraint_name.text()));
-                                    }
-                                }
+                            if add_constraint.not_valid().is_some()
+                                && let Some(constraint) = add_constraint.constraint()
+                                && let Some(constraint_name) = constraint.name()
+                            {
+                                not_valid_names.insert(Identifier::new(&constraint_name.text()));
                             }
                         }
                         _ => (),
@@ -126,6 +124,13 @@ pub(crate) fn constraint_missing_not_valid(ctx: &mut Linter, parse: &Parse<Sourc
                                 continue;
                             }
                         }
+                        if let Some(ast::Constraint::PrimaryKeyConstraint(pk)) =
+                            add_constraint.constraint()
+                        {
+                            if pk.using_index().is_some() {
+                                continue;
+                            }
+                        }
 
                         ctx.report(Violation::for_node(
                             Rule::ConstraintMissingNotValid,
@@ -206,6 +211,15 @@ ALTER TABLE distributors VALIDATE CONSTRAINT distfk;
         assert_eq!(errors.len(), 0);
     }
 
+    #[test]
+    fn adding_using_index_ok() {
+        let sql = r#"
+ALTER TABLE account ADD CONSTRAINT account_pk PRIMARY KEY USING INDEX account_pk_idx;
+        "#;
+        let errors = lint(sql, Rule::ConstraintMissingNotValid);
+        assert_eq!(errors.len(), 0);
+    }
+
     #[test]
     fn adding_check_constraint_err() {
         let sql = r#"
