@@ -1,9 +1,10 @@
 use squawk_syntax::{
     Parse, SourceFile,
     ast::{self, AstNode},
+    identifier::Identifier,
 };
 
-use crate::{Linter, Rule, Violation, identifier::Identifier};
+use crate::{Linter, Rule, Violation};
 
 use super::constraint_missing_not_valid::tables_created_in_transaction;
 
@@ -32,12 +33,14 @@ pub(crate) fn disallow_unique_constraint(ctx: &mut Linter, parse: &Parse<SourceF
                             if unique_constraint.using_index().is_none()
                                 && !tables_created.contains(&Identifier::new(&table_name))
                             {
-                                ctx.report(Violation::new(
-                                    Rule::DisallowedUniqueConstraint,
-                                    message.to_string(),
-                                    unique_constraint.syntax().text_range(),
-                                    help.to_string(),
-                                ));
+                                ctx.report(
+                                    Violation::for_node(
+                                        Rule::DisallowedUniqueConstraint,
+                                        message.to_string(),
+                                        unique_constraint.syntax(),
+                                    )
+                                    .help(help),
+                                );
                             }
                         }
                     }
@@ -45,12 +48,14 @@ pub(crate) fn disallow_unique_constraint(ctx: &mut Linter, parse: &Parse<SourceF
                         for constraint in add_column.constraints() {
                             if let ast::Constraint::UniqueConstraint(unique_constraint) = constraint
                             {
-                                ctx.report(Violation::new(
-                                    Rule::DisallowedUniqueConstraint,
-                                    message.to_string(),
-                                    unique_constraint.syntax().text_range(),
-                                    help.to_string(),
-                                ));
+                                ctx.report(
+                                    Violation::for_node(
+                                        Rule::DisallowedUniqueConstraint,
+                                        message.to_string(),
+                                        unique_constraint.syntax(),
+                                    )
+                                    .help(help),
+                                );
                             }
                         }
                     }
@@ -65,7 +70,10 @@ pub(crate) fn disallow_unique_constraint(ctx: &mut Linter, parse: &Parse<SourceF
 mod test {
     use insta::assert_debug_snapshot;
 
-    use crate::{Rule, test_utils::{lint, lint_with_assume_in_transaction}};
+    use crate::{
+        Rule,
+        test_utils::{lint, lint_with_assume_in_transaction},
+    };
 
     #[test]
     fn adding_unique_constraint_err() {
