@@ -10,7 +10,7 @@ pub(crate) fn renaming_table(ctx: &mut Linter, parse: &Parse<SourceFile>) {
     for stmt in file.stmts() {
         if let ast::Stmt::AlterTable(alter_table) = stmt {
             for action in alter_table.actions() {
-                if let ast::AlterTableAction::RenameTable(rename_table) = action {
+                if let ast::AlterTableAction::RenameTo(rename_table) = action {
                     ctx.report(Violation::for_node(
                         Rule::RenamingTable,
                         "Renaming a table may break existing clients.".into(),
