@@ -33,8 +33,8 @@ fn parser_ok(fixture: Fixture<&str>) {
         errors.is_empty(),
         "tests defined in the `ok` can't have parser errors."
     );
-    // skipping pg17 specific stuff since our parser isn't using the latest parser
-    if !test_name.ends_with("pg17") {
+    // skipping pg17/pg18 specific stuff since our parser isn't using the latest parser
+    if !test_name.ends_with("pg17") && !test_name.ends_with("pg18") {
         let pg_result = pg_query::parse(content);
         if let Err(e) = &pg_result {
             assert!(
@@ -100,6 +100,11 @@ fn regression_suite(fixture: Fixture<&str>) {
     }, {
       assert_snapshot!(snapshot_name, errors.join(""));
     });
+
+    assert!(
+        errors.is_empty(),
+        "tests defined in the regression suite can't have parser errors."
+    );
 }
 
 fn parse_text(text: &str) -> (String, Vec<std::string::String>) {
